package com.akamai.ampdemo;

import android.app.Activity;
import android.os.Bundle;
import android.view.WindowManager;

import com.akamai.amp.media.VideoPlayerContainer;
import com.akamai.amp.media.VideoPlayerView;
import com.akamai.amp.media.elements.AMPLibraryInfo;
import com.akamai.amp.media.elements.MediaResource;
import com.akamai.amp.media.errors.ErrorType;
import com.akamai.amp.media.exowrapper2.drm.DrmHandler;
import com.akamai.amp.media.exowrapper2.drm.DrmScheme;
import com.akamai.amp.utils.LogManager;

import java.util.HashMap;

public class MainActivity extends Activity
        implements VideoPlayerContainer.VideoPlayerContainerCallback {

    private final static String LOG_TAG = AMPLibraryInfo.NAME;
    private final static String AMP_LICENSE = "BtvXWK8rlDMO8uWHJcnKB84uPUOQYCI8UKi9jGUgG5aGrKCdiKOsFVA00spK8fs7WDdZ9qNk5ztdMn1yWiam1g==";

    private final static String WIDEVINE_VIDEO_URL = "https://willzhanmswest.streaming.mediaservices.windows.net/609f4f57-1e5b-4898-90b1-81c574b2e8e3/VfE.ism/manifest(format=mpd-time-csf)";
    private static final String WIDEVINE_LICENSE_URL = "https://willzhanmswest.keydelivery.mediaservices.windows.net/Widevine/?kid=4c241420-4ec4-42cb-9551-e9eb988d2911";

    private final static String WIDEVINE_VIDEO_URL2 = "https://storage.googleapis.com/shaka-demo-assets/angel-one-widevine-hls/hls.m3u8";
    private static final String WIDEVINE_LICENSE_URL2 = "https://cwip-shaka-proxy.appspot.com/no_auth";

    private static final String PLAYREADY_VIDEO_URL = "http://playready.directtaps.net/smoothstreaming/SSWSS720H264PR/SuperSpeedway_720.ism";
    private static final String PLAYREADY_LICENSE_URL = null;


    private VideoPlayerContainer videoPlayerContainer;
    private VideoPlayerView videoPlayerView;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);

        videoPlayerContainer = findViewById(R.id.playerViewCtrl);
        videoPlayerContainer.addVideoPlayerContainerCallback(this);

        //addRequestHeaders();

        // Set DRM Security Level with Fixed DrmHandler L1/L3 Value.
        //videoPlayerContainer.setDRMSecurityLevel(DrmHandler.L1);

        videoPlayerContainer.prepareResource(WIDEVINE_VIDEO_URL, DrmScheme.WIDEVINE, WIDEVINE_LICENSE_URL);
        //videoPlayerContainer.prepareResource(WIDEVINE_VIDEO_URL2, DrmScheme.WIDEVINE, WIDEVINE_LICENSE_URL2);
        //videoPlayerContainer.prepareResource(PLAYREADY_VIDEO_URL, DrmScheme.PLAYREADY, PLAYREADY_LICENSE_URL);
    }

    private void addRequestHeaders() {
        HashMap<String, String> headers = new HashMap<>();
        //headers.put("TestHeader","TestValue-ABCDE-12345");
        headers.put("Authorization","Bearer=eyJhbGciOiJFUzI1NiIsInRUVs9QFi0q3wsuf8rFIzspf7oPa9EFDg");
        headers.put("Content-Type", "Application/json");
        videoPlayerContainer.setRequestHeaders(headers);
    }

    @Override
    public void onResourceReady(MediaResource mediaResource) {
        videoPlayerView = videoPlayerContainer.getVideoPlayer();
        videoPlayerView.setLicense(AMP_LICENSE);
        videoPlayerView.setLogEnabled(true);

        videoPlayerView.play(mediaResource);
    }

    @Override
    public void onVideoPlayerCreated() {
        LogManager.log(LOG_TAG, "onVideoPlayerCreated()");
    }

    @Override
    public void onResourceError(ErrorType errorType, Exception exception) {
        LogManager.error(LOG_TAG, "onResourceError() " + exception);
    }

    @Override
    protected void onResume() {
        LogManager.log(LOG_TAG, "onResume");
        if (videoPlayerView != null) videoPlayerView.onResume();
        super.onResume();
    }

    @Override
    protected void onPause() {
        LogManager.log(LOG_TAG, "onPause");
        if (videoPlayerView != null) videoPlayerView.onPause();
        super.onPause();
    }

    @Override
    protected void onDestroy() {
        LogManager.log(LOG_TAG, "onDestroy");
        if (videoPlayerView != null) videoPlayerView.onDestroy();
        super.onDestroy();
    }

}
